/* Search by keyword CSS file */

#id_user_templates li{
    overflow: auto;
}

#id_user_templates li>label{
    display: flex;
    align-items: center;
}
#id_global_templates li{
    overflow: auto;
}

#id_global_templates li>label{
    display: flex;
    align-items: center;
}

.search_button {
    height: 2.5em;
    line-height: 0;
    min-width: 0;
    width: 6em;
    margin: 0.15em 1em;
    float: right;
}

.ui-autocomplete-input {
    margin-top: 0.2em;
}

.ui-autocomplete-input::placeholder { /* Chrome, Firefox, Opera, Safari 10.1+ */
  color: #808080;
  opacity: 0.5; /* Firefox */
}

.ui-autocomplete-input:-ms-input-placeholder { /* Internet Explorer 10-11 */
  opacity: 0.5; /* Firefox */
  color: #808080;
}

.ui-autocomplete-input::-ms-input-placeholder { /* Microsoft Edge */
  opacity: 0.5; /* Firefox */
  color: #808080;
}

.selectAllGlobalTemplateButton {
    color: #0043de;
    font-size: 0.5em;
}

.selectAllUserTemplateButton {
    color: #0043de;
    font-size: 0.5em;
}

ul.tagit {
    width: 100%;
    height: 2.8em;
    margin: 0;
    border-radius: 5px;
    -webkit-border-radius: 5px;
    border: none !important;
    padding-top: 0.35em;
    -webkit-box-shadow: 0 3px 10px 0 #B5B5B5;
    box-shadow: 0 3px 10px 0 #B5B5B5;
}

ul.tagit li.tagit-choice-editable {
    height: 1.65em;
    padding: 0 20px 0 0.2em;
    border-radius: .3em;
    -webkit-border-radius: .3em;
    border: 1px solid #b1b1b1;
    background-color: #efefef;
    color: #4a4a4a;
    font-family: 'Source Sans Pro', sans-serif;
    width: auto !important;
}

.tagit {
    cursor: text;
}

ul.tagit li.tagit-new {
    padding: 0.25em 20px 0.25em 0.25em;
    width: auto !important;
}

/* Enlarge the tag only if the placeholder is present */
ul.tagit li.tagit-new .ui-autocomplete-input:placeholder-shown {
    width: 40rem !important;
}

ul.tagit li.tagit-new.tagit-choice-editable {
    padding: 0 20px 0 0.2em;
}

.tagit-close {
    text-decoration: none;
    border: 0;
    cursor: pointer;
}

.tagit-label {
    margin-left: 0.2em;
}

.list-group input {
    margin-right: 8px;
}

.list-group label {
    font-weight: 400;
}

.card-header+.list-group li:first-child {
    border-top: 0;
}

.list-group li:first-child {
    border-top-left-radius: .25rem;
    border-top-right-radius: .25rem;
}

.list-group ul {
    margin: 0 0 0 0;
}

.list-group li {
    position: relative;
    display: block;
    padding: .75rem 1.25rem;
    background-color: #fff;
    border-bottom: 1px solid rgba(0,0,0,.125);
    border-left: 1px solid rgba(0,0,0,.125);
    border-right: 1px solid rgba(0,0,0,.125);
}

.group-list-side-border {
    border-right: 1px solid rgba(0,0,0,.125);
    border-left: 1px solid rgba(0,0,0,.125);
    border-radius: 2px;
    overflow: scroll;
}

.tools-menu li {
    padding-top: 0;
    padding-bottom: 0;
    padding-left: 10px;
}

.tools-menu i {
    padding-right: 5px;
}

.tools-menu a {
    display: contents !important;
}

span.fancytree-title {
    width: 12em;
}

.search-bar-wrapper {
    margin-left: 1.4em;
    margin-bottom: 2em;
    float: left;
    width: calc(100% - 10em);
}

ul.tagit li.operator-bg-success-color {
    background-color: #deeeff;
}

ul.tagit li.operator-bg-error-color {
    background-color: #ffc1c1;
}


ul.tagit li.operator-bg-success-color input {
    margin-top: 3px;
}

ul.tagit li.operator-bg-error-color input{
    margin-top: 3px;
}