{% if data.search_form.global_templates|length > 0 or data.search_form.user_templates|length > 0 %}
{% if data.search_form.global_templates|length > 0 %}
<div class="card">
    <div class="card-header">
        <div class="row">
            <div class="col-md-8">
                Filter by Template
            </div>
            <div class="pl-0 col-md-4">
                <div class="float-right">
                    <a class="selectAllGlobalTemplateButton" href="javascript:void(0)">
                        Select All
                    </a>
                </div>
            </div>
        </div>
    </div>
</div>
<div class="list-group">
    {{ data.search_form.global_templates }}
</div>
{% endif %}
{% if data.search_form.user_templates|length > 0 %}
<div class="card">
    <div class="card-header">
        <div class="row">
            <div class="col-md-9">
                Filter by User Template
            </div>
            <div class="pl-0 col-md-3">
                <div class="float-right">
                    <a class="selectAllUserTemplateButton" href="javascript:void(0)">
                        Select All
                    </a>
                </div>
            </div>
        </div>
    </div>
</div>
<div class="list-group">
    {{ data.search_form.user_templates }}
</div>
    {% endif %}
{% endif %}
